DrainError

Enum DrainError 

pub enum DrainError {
    Fmt(Error),
    CompoundError(usize),
}
Represents an error which can occur when draining errors from the DiagnosticHandler::drain() and DiagnosticHandler::report_and_drain.

Variants



Fmt(Error)

Defines that the error occured when attempting to write the diagnostic to the output buffer.



CompoundError(usize)

Defines that one-or-more errors were reported during the drain, which are not propogating upwards to the calling function.

The variant defines the number of errors which were reported. Note that this number does not include non-errors such as warnings, nor does it count any sub-diagnostics, such as labels or related errors.