pub struct GraphicalRenderer {
pub theme: Theme,
pub width: usize,
pub padding: usize,
pub gutter_margin: usize,
pub context_lines: usize,
pub use_colors: bool,
pub highlight_source: bool,
/* private fields */
}Expand description
Fields
theme: ThemeDefines the theme of the renderer.
The theme defines which colors and symbols to use when rendering diagnostics.
width: usizeDefines the maximum length of the terminal.
padding: usizeDefines the padding to use per level of identation.
gutter_margin: usizeDefines the margin to use in the gutter of snippets.
context_lines: usizeDefines the amount of lines surrounding a label to include as context.
use_colors: boolDefines whether to use colors in the output.
highlight_source: boolDefines whether to highlight the source code where a label
is marked. This is only used if use_colors is true.
Implementations
Sourceimpl GraphicalRenderer
impl GraphicalRenderer
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new instance of GraphicalRenderer with default settings.